@@ -278,6 +278,7 @@ class ComicDb():
 		except:
 			return 0
 
+
 	def store_last(self, sid = 0):
 		try:
 			idf = open(self.dbfile + ".last", 'w')
@@ -1082,9 +1083,11 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 
 		self.e_goweb.add(self.label)
 		self.e_goweb.set_events(gtk.gdk.BUTTON_RELEASE_MASK)
-		self.e_goweb.connect("button-release-event", self.view_comic)
+		self.e_goweb.connect("button-release-event", self.view_comic_web)
 
 		self.e_open.add(self.comic_image)
+		self.e_open.set_events(gtk.gdk.BUTTON_PRESS_MASK)
+		self.e_open.connect("button-press-event", self.view_comic)
 
 		# self.e_switch.add(self.switch)
 		self.e_switch.set_events(gtk.gdk.BUTTON_PRESS_MASK|gtk.gdk.BUTTON_RELEASE_MASK|gtk.gdk.LEAVE_NOTIFY)
@@ -1287,12 +1290,20 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 		self.draw(widget, "0")
 
 	# no fancy cairo stuff here. simply launches url in browser.
-	def view_comic(self, widget, event):
+	def view_comic_web(self, widget, event):
 		if not event.type == gtk.gdk.BUTTON_RELEASE:
 			return False
 		link = self.db.get_link()
 		self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (link,))
 
+	# simply launches image in browser.
+	def view_comic(self, widget, event):
+		if not event.type == gtk.gdk._2BUTTON_PRESS:
+			return False
+		#link = self.db.get_link()
+		link = 'file:///home/user/MyDocs/.comics/' + self.db.comic + '/' + self.db.db[self.db.currentcomic]['filename']
+		self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (link,))
+
 
 
 	# this function modifies the image to fit the widget and then returns it.
